<?php

/**
 * @file
 * Describes hooks provided by the List module.
 */

use Drupal\Component\Utility\Html;

/**
 * Hook_list_formatter_field_list_info().
 *
 * Declare new field types/callbacks that are available as text formatter lists.
 */
function hook_list_formatter_field_info() {
  $info = [];

  // Key array with module name.
  $info['example'] = [
    // An array of fields that List can be used on. Typically you
    // would add the name(s) of the fields you are integrating here.
    'fields' => ['example', 'example_other'],
    // Callback to process $items from hook_field_formatter_view, and format
    // an array of values that will be used in the displayed list.
    'callback' => 'list_formatter_example_field_create_list',
    // An array of settings/default settings that will be used. Anything
    // defined in here will be merged into the list_formatter_contrib array in
    // The field formatter info. If your settings are not declared here, no
    // defaults wil exist.
    'settings' => [
      'list_formatter_example_setting' => TRUE,
    ],
  ];

  return $info;
}

/**
 * Sample callback implementation.
 *
 * @see list_formatter_default_field_create_list()
 */
function list_formatter_example_field_create_list($entity_type, $entity, $field, $instance, $langcode, $items, $display) {
  $list_items = [];

  foreach ($items as $delta => $item) {
    $list_items[$delta] = Html::escape($item['value']);
  }

  return $list_items;
}

/**
 * Hook_list_formatter_field_list_info_alter().
 */
function hook_list_formatter_field_info_alter(&$info) {
  // Change the callback used for fields from the text module.
  $info['text']['callback'] = 'list_formatter_example_text_callback';
}

/**
 * Hook_list_formatter_field_formatter_settings_form_alter().
 */
function hook_list_formatter_field_formatter_settings_form_alter(&$form, &$form_state, $context) {
  // Sample form element here.
}
